@@ -1,8 +1,9 @@
 package IP::Country::DB_File;
-BEGIN {
-  $IP::Country::DB_File::VERSION = '2.01';
+{
+  $IP::Country::DB_File::VERSION = '2.10';
 }
 use strict;
+use warnings;
 
 # ABSTRACT: IP to country translation based on DB_File
 
@@ -67,17 +68,19 @@ sub db_time {
 
 1;
 
-
+__END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 IP::Country::DB_File - IP to country translation based on DB_File
 
 =head1 VERSION
 
-version 2.01
+version 2.10
 
 =head1 SYNOPSIS
 
@@ -145,13 +148,9 @@ Nick Wellnhofer <wellnhofer@aevum.de>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2011 by Nick Wellnhofer.
+This software is copyright (c) 2014 by Nick Wellnhofer.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
-
-__END__
-
